# Wildcatter

[![PyPI](https://img.shields.io/pypi/v/wildcatter.svg)][pypi_]
[![Status](https://img.shields.io/pypi/status/wildcatter.svg)][status]
[![Python Version](https://img.shields.io/pypi/pyversions/wildcatter)][python version]
[![License](https://img.shields.io/pypi/l/wildcatter)][license]

[![Read the documentation at https://wildcatter.readthedocs.io/](https://img.shields.io/readthedocs/wildcatter/latest.svg?label=Read%20the%20Docs)][read the docs]

[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]

[pypi_]: https://pypi.org/project/wildcatter/
[status]: https://pypi.org/project/wildcatter/
[python version]: https://pypi.org/project/wildcatter
[read the docs]: https://wildcatter.readthedocs.io/
[black]: https://github.com/psf/black

Reinforcement learning framework for well placement and optimization

## Features

- TODO

## Requirements

- TODO

## Installation

You can install _Wildcatter_ via [pip] from [PyPI]:

```console
$ pip install wildcatter
```

## Usage

Please see the [Command-line Reference] for details.

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide].

## License

Distributed under the terms of the [Apache 2.0 license][license],
_Wildcatter_ is free and open source software.

## Issues

If you encounter any problems,
please [file an issue] along with a detailed description.

## Credits

This project was generated from [@cjolowicz]'s [Hypermodern Python Cookiecutter] template.

[@cjolowicz]: https://github.com/cjolowicz
[pypi]: https://pypi.org/
[hypermodern python cookiecutter]: https://github.com/cjolowicz/cookiecutter-hypermodern-python
[file an issue]: https://github.com/GeoML-SIG/wildcatter/issues
[pip]: https://pip.pypa.io/

<!-- github-only -->

[license]: https://github.com/GeoML-SIG/wildcatter/blob/main/LICENSE
[contributor guide]: https://github.com/GeoML-SIG/wildcatter/blob/main/CONTRIBUTING.md
[command-line reference]: https://wildcatter.readthedocs.io/en/latest/usage.html
